function [spot, bb] = gtGetSummedDifSpot(difID, parameters, connected, info)
% returns the summed difspot image (saved as difspot%05d.edf) or in difblobtable
% 360degree scan convention - ak 10/2007
% speed up by providing edfheader info

    if ~exist('parameters','var')
        disp('loading parameters...');
        load('parameters.mat');
    end

    % connect to database
    if (~exist('connected', 'var'))
        connected = false;
    end

    if (~connected)
        gtDBConnect()
    end

    if (~exist('info', 'var'))
        info = [];
    end

    bb = [];

    base_dir = fullfile(parameters.acq.dir, '2_difspot');
    sub_dir = fullfile(base_dir, sprintf('%05d', difID - mod(difID, 1e4)));
    filename = fullfile(sub_dir, sprintf('difspot%05d.edf', difID) );

    if (exist(filename, 'file'))
        % read the edf file
        spot = edf_read(filename, [], [], info);
        if (nargout == 2)
            query = sprintf([ ...
                'SELECT BoundingBoxXOrigin, BoundingBoxYOrigin, ' ...
                '       BoundingBoxXSize, BoundingBoxYSize' ...
                '   FROM %sdifspot' ...
                '   WHERE difspotID = %d'], parameters.acq.name, difID);
            [bb(1), bb(2), bb(3), bb(4)] = mym(query);
        end
    else
        try
            tablename = parameters.acq.name;
            [vol, bb] = gtDBBrowseDiffractionVolume(tablename, difID);
            spot = sum(vol, 3);
        catch Mexc
            gtPrintException(Mexc, 'cannot find difspot as edf or as difblob!')
        end
    end
end
