function hf = gtDrawSampleGeometry(rad, bot, top)
% GTSAMPLEGEOMETRY  Draws sample envelope and axis
%     hf = gtDrawSampleGeometry(rad, bot, top)
%     ----------------------------------------
%
%     INPUT:
%       rad = parameters.labgeo.samenvrad
%       bot = parameters.labgeo.samenvbot
%       top = parameters.labgeo.samenvtop
%
%     OUTPUT:
%       hf = figure handle
%
%     Version 002 26-02-2013 by LNervo
%       Modified ticks for axes: equal spacing for ticks in the sample volume
%       (grid on)
%
%     Version 001 15-11-2012 by LNervo


hf = figure();

color = [0.501960813999176 0.501960813999176 0.501960813999176];

% Create axes
set(gca,'ZMinorTick','on')
set(gca,'ZColor',color);
set(gca,'YMinorTick','on');
set(gca,'YColor',color);
set(gca,'XMinorTick','on');
set(gca,'XColor',color);
set(gca,'FontSize',12);
set(gca,'Visible','on');
set(gca,'Box','on');
set(gca,'XGrid','on');
set(gca,'YGrid','on');
set(gca,'ZGrid','on');
% Create xlabel
xlabel('X','Color',color);
% Create ylabel
ylabel('Y','Color',color);
% Create zlabel
zlabel('Z','Color',color);

h = rotate3d(hf);
set(h,'RotateStyle','box','Enable','on');
hold(gca,'on');

t = 1:360;
circx = cosd(t)*rad;
circy = sind(t)*rad;
circbotz(1:360) = bot;
circtopz(1:360) = top;

% sample envelope : circles
plot3(circx, circy, circbotz, 'k-', 'Linewidth', 1);
plot3(circx, circy, circtopz, 'k-', 'Linewidth', 1);
% sample envelope : axis
plot3([0 0],[0 0],[bot top],'k.-.','Linewidth',1);
% sample envelope : lateral bars
plot3([-rad -rad],[0 0],[bot top],'k.-','Linewidth',1);
plot3([0 0],[-rad -rad],[bot top],'k.-','Linewidth',1);
plot3([rad rad],[0 0],[bot top],'k.-','Linewidth',1);
plot3([0 0],[rad rad],[bot top],'k.-','Linewidth',1);

% lab system : x y z vectors
quiver3(-rad*1.2,0,0,2.4*rad,0,0,0,'r');
quiver3(0,-rad*1.2,0,0,2.4*rad,0,0,'k');
quiver3(0,0,bot*1.2,0,0,(top-bot)*1.2,0,'b');

negat = false(1,3);
if bot < 0
  bot = abs(bot);
  negat(2) = true;
elseif top < 0
  top = abs(top);
  negat(3) = true;
end
n = floor(log(abs([rad bot top]))./log(10));
step = 10.^n;

limits = ceil([rad bot top]./step).*step;
limits(2:3) = max([bot top], limits(2:3));
limits(negat) = -limits(negat);

set(gca,'XTick',-limits(1):step(1):limits(1))
set(gca,'YTick',-limits(1):step(1):limits(1))
set(gca,'ZTick',limits(2):step(2):limits(3))

% axis limits
axis vis3d
axis equal

end
