function [hp,hl] = gtPlotGrainUnitCell(vertices, caxis, faces, cmap, hlight, linecolor, alpha)
% GTPLOTGRAINUNITCELL  Draws the grain unit cell given its properties
%
%     [hp,hl] = gtPlotGrainUnitCell(vertices, caxis, faces, cmap, hlight, linecolor, alpha)
%     -------------------------------------------------------------------------------------
%     INPUT:
%       vertices    = vertices coordinates <double Nx3>
%       caxis       = coordinates of the c-axis <double 2x3>
%       faces       = faces <double>
%       cmap        = facecolor property <double 1x3>
%       hlight      = flag to highlight the unit cell (thicker edges) <logical>
%       linecolor   = linecolor property (edges)
%       alpha       = facealpha property <double>
%
%     OUTPUT:
%       hp          = patch handle
%       hl          = c-axis handle (if existing)
%
%     Version 002 06-06-2013 by LNervo



if iscell(faces)
    hp = cellfun(@(num) ...
             patch('Vertices', vertices, 'Faces', num, ...
                   'FaceColor', cmap, ...
                   'EdgeColor', linecolor, 'FaceAlpha', alpha), faces );
else
    facecolor = repmat(cmap,size(faces,1),1);
    hp = patch('Vertices', vertices, 'Faces', faces, ...
               'FaceColor', facecolor, ...
               'EdgeColor', linecolor, 'FaceAlpha', alpha);
end
% draw the caxis
if ~isempty(caxis)
    hl = line(caxis(:,1),caxis(:,2),caxis(:,3),'Color',linecolor);
else
    hl = [];
end

if hlight
    set(hp,'LineWidth',2)
    if hlight, set(hl, 'LineWidth',2); end
else
    set(hp,'LineWidth',1)
    if hlight, set(hl, 'LineWidth',1); end
end


end  % end of function
