function [Ccell,Cmat] = gtReadTextFile(filename, formatS, delimiter, comments, minsize)
% GTREADTEXTFILE  Reads textfiles into matrices
%
%     [Ccell, Cmat] = gtReadTextFile(filename, format, delimiter, comments, minsize)
%     ------------------------------------------------------------------------------
%
%     INPUT:
%       filename  = text file to be read <string>
%       formatS   = format pattern as in fprintf <string> i.e. '%f %f %f'
%       delimiter = character as delimiter i.e. ' '
%       comments  = character as comments i.e. '#'
%       minsize   = minimum size of element to be consider as object (like
%                   matrix 3x3 or vector 1x3)
%
%     OUTPUT:
%       Ccell = content of the text file (read as columns) <cell> 
%       Cmat  = read matrix <double>
%
%
%     Version 001 03-12-2012 by LNervo


fid = fopen(filename,'r');
C = textscan(fid, formatS,...
             'Delimiter', delimiter,...
             'CommentStyle', comments);
fclose(fid);

Cmat = cell2mat(C);

if minsize(1)>0 && minsize(2)>0
    for ii = 1 : size(Cmat,1)/minsize(1)
        C{ii} = Cmat((ii-1)*minsize(1)+1:minsize(1)*ii,1:minsize(2));
    end
end

Ccell = C;

end % end of function
