function strategy = gtIndexDefaultStrategy()
% GTINDEXDEFAULTSTRATEGY  Stores and returns the default parameter values 
%                         for the indexing strategy.
%     strategy = gtIndexDefaultStrategy()
%     -----------------------------------


% No. of iterations (linear extension of tolerances from 'beg' to 'end'):
strategy.iter = 5;

% Absolute extension to the Rodrigues fundamental zone
strategy.rfzext = 0.005; 

% Tolerances for building grains in the first iteration:
strategy.b.beg.ang     = 0.05;  % angular difference in degrees
strategy.b.beg.int     = 5;     % max. intensity ratio
strategy.b.beg.bbxs    = 1.3;   % max. bbox x size ratio
strategy.b.beg.bbys    = 1.3;   % max. bbox y size ratio
strategy.b.beg.distf   = 0.1 ;  % size factor for max. distances between diff. paths
strategy.b.beg.distmax = 0.002; % max. absolut limit for distances between diff. paths in lab unit (mm)
strategy.b.beg.ming    = 5;     % min. no. of Friedel pairs in a grain  

% Tolerances for building grains in the last iteration:
strategy.b.end.ang     = 1;
strategy.b.end.int     = 50;
strategy.b.end.bbxs    = 3;
strategy.b.end.bbys    = 2;
strategy.b.end.distf   = 0.3;
strategy.b.end.distmax = 0.02;
strategy.b.end.ming    = 4;

% Tolerances for merging grains in the first iteration:
strategy.m.beg.bbxs    = strategy.b.beg.bbxs; % max. ratio of average bbox x sizes
strategy.m.beg.bbys    = strategy.b.beg.bbys; % max. ratio of average bbox y sizes
strategy.m.beg.int     = strategy.b.beg.int;  % max. ratio of average intensities
strategy.m.beg.distf   = 0.5;  % size factor for maximum distance between grain centers
strategy.m.beg.distmin = 0;    % min. limit for distance tolerance in lab unit (mm)
strategy.m.beg.distmax = Inf;  % max. limit for distance tolerance in lab unit (mm)
strategy.m.beg.angf    = 0;    % max. angular deviation (std)
strategy.m.beg.angmin  = 1;    % min. limit for angular tolerance in angles
strategy.m.beg.angmax  = 1;    % max. limit for angular tolerance in angles

% Tolerances for merging grains in the last iteration:
strategy.m.end.bbxs    = strategy.b.end.bbxs;
strategy.m.end.bbys    = strategy.b.end.bbys;
strategy.m.end.int     = strategy.b.end.int;
strategy.m.end.distf   = 0.5; 
strategy.m.end.distmin = 0;   
strategy.m.end.distmax = Inf; 
strategy.m.end.angf    = 0;
strategy.m.end.angmin  = 1.5; 
strategy.m.end.angmax  = 1.5; 

% Tolerance for statistical fitting of unindexed reflections to grains
strategy.s.stdf = 4;     % limit in std to accept a new reflection

% Tolerance for statistical rejection of indexed reflections from grains
strategy.x.stdf = 4;     % limit in std to consider a reflection as outlier

end % end of function


