function structure = build_structure(list,  sep,  debug)
% BUILD_STRUCTURE_V0  Build some structure starting from a list template in 'list'
%     structure = build_structure(list,  sep,  debug)
%     -------------------------------------------
%     INPUT:
%       list = list of fields contents in template_list##.mat <cell Nx3>
%       sep  = separator for sub-structures in list struct {'__'}
%              i.e. list.index---strategy --> sep = '---' if 'strategy' is a
%                   sub-structure of 'index'.
%                   PS. list.match_calib --> 'match_calib' is a field of
%                       'list'. 'calib' is a sub-structure of 'match'.
%
%     OUTPUT:
%       structure     = structure built from 'list' <struct>
%       substructures = array of sub-structures found in each field of
%                       'structure' <char>
%
%
%     Version 001 18-11-2011 by LNervo
%       For each sub-structure an empty structure is created properly and
%       the name is given in the output 'substructures'

% default separator is '__'
if ~exist('sep', 'var') || isempty(sep)
    sep = '__';
end
if ~exist('debug', 'var') || isempty(debug)
    debug = false;
end

out = GtConditionalOutput(debug);

structure = [];
field     = struct();


if isstruct(list)
    names = fieldnames(list);
    newnames = fieldnames(list);
    
    for l = 1:length(names)
        if ~isempty(strfind(names{l}, sep))
            tmp = names{l};
            tmp = strrep(tmp, sep, '.'); % default separator is '__'
            newnames{l} = tmp;
        end
    end
    
    for ii = 1:length(names)
        out.odisp(['### structure ' names{ii} ' ###'])
        if ~isstruct(list.(names{ii}))
            for j = 1:size(list.(names{ii}), 1)
                %list.(names{i}){j, 1}
                if strcmpi(list.(names{ii}){j, 3}, 'char')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = char([]);
                    %out.odisp('Found char...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'double')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = double([]);
                    %out.odisp('Found double...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'single')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = single([]);
                    %out.odisp('Found single...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'int8')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = int8([]);
                    %out.odisp('Found int8...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'logical')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = false;
                    %out.odisp('Found logical...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'cell')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = cell(1, 1);
                    %out.odisp('Found cell...')
                elseif strcmpi(list.(names{ii}){j, 3}, 'struct')
                    field.(names{ii}).(list.(names{ii}){j, 1}) = struct();
                    out.odisp('Found structure...')
                else
                    field.(names{ii}).(list.(names{ii}){j, 1}) = NaN;
                end
                
            end % end for j
        else
            out.odisp(['Found structure... Run again the function with input the structure <oldinput>.' names{ii}])
        end % end isstruct
    end % end for i
    
    for ii = 1:length(names)
        if ~strcmp(names{ii}, newnames{ii})
            newname = textscan(newnames{ii}, '%s', 'delimiter', '.');
            newname = newname{1};
            switch size(newname, 1)
                case 1
                    field.(newname{1}) = field.(names{ii});
                case 2
                    field.(newname{1}).(newname{2}) = field.(names{ii});
                case 3
                    field.(newname{1}).(newname{2}).(newname{3}) = field.(names{ii});
                case 4
                    field.(newname{1}).(newname{2}).(newname{3}).(newname{4}) = field.(names{ii});
                case 5
                    field.(newname{1}).(newname{2}).(newname{3}).(newname{4}).(newname{5}) = field.(names{ii});
            end
            field = rmfield(field, names{ii});
        end
    end
    
    structure = field;
else
    disp('Please give as input a structure');
    return;
end

end % end function
